# NOTE: In general we should be carefull with importing additional modules in __init__.py because 
# they are imported any time any module or sub-module is required
# import `ColaboFlowGo` class from the local (notice: `.`) file `colaboflow_go`
from .colaboflow_go_client import ColaboFlowGo
from .colaboflow_go_demo import ColaboFlowGoDemo

# provide the `ColaboFlowGo` class directly importable from the `go` namespace
__all__ = ['ColaboFlowGo', 'ColaboFlowGoDemo']



# -*- coding: utf-8 -*-
#!/usr/bin/python

from __future__ import print_function

import random

from datetime import datetime
# import dateutil.parser

import grpc

from . import go_pb2
from . import go_pb2_grpc

class ColaboFlowGo():
    goRequestDefault = None
    stubDefault = None

    def __init__(self, socketUrl=None, reuseClient=True):
        
        print("ColaboFlowGo::__init__");

        if not socketUrl:
            socketUrl = 'localhost:50506'
        self.socketUrl = socketUrl

        # create new stub client only if requested or
        # there is no defualt stub client one yet
        if not reuseClient or not ColaboFlowGo.stubDefault:
            print("Initializing gRPC at: %s" % (socketUrl))
            self.channel = grpc.insecure_channel(socketUrl)
            # to call service methods, we first need to create a stub.
            print(go_pb2_grpc)
            self.stub = go_pb2_grpc.FlowsHostStub(self.channel)
            ColaboFlowGo.stubDefault = self.stub
        else:
            self.stub = ColaboFlowGo.stubDefault



    def executeActionSync(self, actionExecuteRequest):
        actionExecuteReply = self.stub.executeActionSync(actionExecuteRequest)
        if not actionExecuteReply.id:
            print("Server returned incomplete actionExecuteReply")
        else:
            print("actionExecuteReply is %s" % (actionExecuteReply))
        return actionExecuteReply



# -*- coding: utf-8 -*-
#!/usr/bin/python

from __future__ import print_function

import random

from datetime import datetime
# import dateutil.parser

class ColaboFlowGoDemo():
    goRequestDefault = None
    stubDefault = None

    def __init__(self, flowName="basic-flow"):
        
        print("[ColaboFlowGoDemo] new flow created: %s" % (flowName))
        self.flow = []
        self.flowPointer = 0

    # ---------------------------------------------------------------------------------------
    # NOTE: SEQUENTIAL DATA FLOW: In this scenario, user can describe control flow order,
    # but the data flow HAS to follow the same control-flow 
    # (so data output of action `i` is the input for the action `i+1`)
    # ---------------------------------------------------------------------------------------

    # Add action in a sequence with
    # - action name and 
    # = reference to the function implementing it
    def addActionAsFunction(self, funcRef, actionName):
        action = {
            'name': actionName,
            'funcRef': funcRef
        }
        self.flow.append(action)
        # print(len(self.flow))
        return self

    # runs functions in a sequence
    # data input for the function `i+1` is data output of the function `i`
    def runWithSequentialDataFlow(self, dataIn):
        print("---")
        for action in self.flow:
            print("running action: ", action['name'])
            func = action['funcRef']
            result = func(dataIn)
            print("result: ", result)
            dataIn = result
            print("---")

    # ---------------------------------------------------------------------------------------
    # NOTE: DESCRIPTIVE_DATA_FLOW: In this way data flow doesn't need to follow control flow
    # but it can be described separtelly
    # ---------------------------------------------------------------------------------------

    # Add action in a sequence with
    # - action name
    # - reference to the function implementing it
    # - inputParameterName name that holds the input parameter
    def addActionAsFunctionWithInputParam(self, funcRef, actionName, inputParameterName=None):
        action = {
            'name': actionName,
            'funcRef': funcRef,
            'inputParameterName': inputParameterName
        }
        self.flow.append(action)
        # print(len(self.flow))
        return self

    def runWithDescriptiveDataFlow(self, dataName, dataIn):
        print("---")
        self.results = {}
        self.results[dataName] = dataIn
        for action in self.flow:
            # print("running action: ", action)
            print("running action: ", action['name'])
            func = action['funcRef']
            inputParameterName = action['inputParameterName']
            result = func(self.results[inputParameterName])
            self.results[action['name']] = result
            print("result: ", result)
            print("---")

    # ---------------------------------------------------------------------------------------
    # NOTE: DESCRIPTIVE_MULTIDATA_FLOW: data flow doesn't follow control flow
    # and it can have multiple input datasets
    # ---------------------------------------------------------------------------------------

    # Add action in a sequence with
    # - action name
    # - reference to the function implementing it
    # - inputParameterNames - list of names that hold input parameters
    def addActionAsFunctionWithInputParams(self, funcRef, actionName, inputParameterNames=None):
        action = {
            'name': actionName,
            'funcRef': funcRef,
            'inputParameterNames': inputParameterNames
        }
        self.flow.append(action)
        # print(len(self.flow))
        return self

    def runWithDescriptiveMultiDataFlow(self, dataName, dataIn):
        print("---")
        self.results = {}
        self.results[dataName] = dataIn
        for action in self.flow:
            # print("running action: ", action)
            print("running action: ", action['name'])
            func = action['funcRef']
            inputParameterNames = action['inputParameterNames']
            inputParameters = []
            for inputParameterName in inputParameterNames:
                  inputParameters.append(self.results[inputParameterName])
            result = func(*inputParameters)
            self.results[action['name']] = result
            print("result: ", result)
            print("---")

    # ---------------------------------------------------------------------------------------
    # NOTE: DESCRIPTIVE_MULTIDATAOUTPUT_FLOW: output data flow can have multiple datasets
    # each with its own name
    # ---------------------------------------------------------------------------------------

    # Add action in a sequence with
    # - action name
    # - reference to the function implementing it
    # - inputParameterNames - list of names that hold input parameters
    def addActionAsFunctionWithOutputParams(self, funcRef, actionName, inputParameterNames=None, outputParameterNames=None):
        action = {
            'name': actionName,
            'funcRef': funcRef,
            'inputParameterNames': inputParameterNames,
            'outputParameterNames': outputParameterNames
        }
        self.flow.append(action)
        # print(len(self.flow))
        return self

    def runWithDescriptiveOutDataFlow(self, dataName, dataIn):
        print("---")
        self.results = {}
        self.results[dataName] = dataIn
        for action in self.flow:
            # print("running action: ", action)
            print("running action: ", action['name'])
            func = action['funcRef']
            inputParameterNames = action['inputParameterNames']
            inputParameters = []
            for inputParameterName in inputParameterNames:
                  inputParameters.append(self.results[inputParameterName])
            outputParameterNames = action['outputParameterNames']
            result = func(*inputParameters)
            if outputParameterNames != None and len(outputParameterNames)>1:
                results = result
                print("results: ", results)
                if(len(outputParameterNames) != len(results)):
                    print("Expected number of parameters: %s, but got %s instead" % 
                          (len(outputParameterNames), len(results)))
                for i in range(len(outputParameterNames)):
                    outputParameterName = outputParameterNames[i]
                    result = results[i]
                    self.results[outputParameterName] = result
                    print("result[%s]: %s" % (i, result))
            else:
                print("result: ", result)
                self.results[action['name']] = result
            print("---")



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from colabo.flow.go import go_pb2 as colabo_dot_flow_dot_go_dot_go__pb2


class ActionsHostStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.executeAction = channel.unary_unary(
        '/colabo.flow.ActionsHost/executeAction',
        request_serializer=colabo_dot_flow_dot_go_dot_go__pb2.ActionExecuteRequest.SerializeToString,
        response_deserializer=colabo_dot_flow_dot_go_dot_go__pb2.ActionExecuteReply.FromString,
        )


class ActionsHostServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def executeAction(self, request, context):
    """rpc checkAction (ActionExecuteRequest) returns (ActionExecuteReply) {}
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ActionsHostServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'executeAction': grpc.unary_unary_rpc_method_handler(
          servicer.executeAction,
          request_deserializer=colabo_dot_flow_dot_go_dot_go__pb2.ActionExecuteRequest.FromString,
          response_serializer=colabo_dot_flow_dot_go_dot_go__pb2.ActionExecuteReply.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'colabo.flow.ActionsHost', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))


class FlowsHostStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.startFlowInstance = channel.unary_unary(
        '/colabo.flow.FlowsHost/startFlowInstance',
        request_serializer=colabo_dot_flow_dot_go_dot_go__pb2.FlowInstanceRequest.SerializeToString,
        response_deserializer=colabo_dot_flow_dot_go_dot_go__pb2.FlowInstanceReply.FromString,
        )
    self.executeActionSync = channel.unary_unary(
        '/colabo.flow.FlowsHost/executeActionSync',
        request_serializer=colabo_dot_flow_dot_go_dot_go__pb2.ActionExecuteRequest.SerializeToString,
        response_deserializer=colabo_dot_flow_dot_go_dot_go__pb2.ActionExecuteReply.FromString,
        )


class FlowsHostServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def startFlowInstance(self, request, context):
    """client asks the host to execute (wherever is expected) the action
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def executeActionSync(self, request, context):
    """client asks the host to execute (wherever is expected) the action
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_FlowsHostServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'startFlowInstance': grpc.unary_unary_rpc_method_handler(
          servicer.startFlowInstance,
          request_deserializer=colabo_dot_flow_dot_go_dot_go__pb2.FlowInstanceRequest.FromString,
          response_serializer=colabo_dot_flow_dot_go_dot_go__pb2.FlowInstanceReply.SerializeToString,
      ),
      'executeActionSync': grpc.unary_unary_rpc_method_handler(
          servicer.executeActionSync,
          request_deserializer=colabo_dot_flow_dot_go_dot_go__pb2.ActionExecuteRequest.FromString,
          response_serializer=colabo_dot_flow_dot_go_dot_go__pb2.ActionExecuteReply.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'colabo.flow.FlowsHost', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: colabo/flow/go/go.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='colabo/flow/go/go.proto',
  package='colabo.flow',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x17\x63olabo/flow/go/go.proto\x12\x0b\x63olabo.flow\"%\n\x13\x46lowInstanceRequest\x12\x0e\n\x06\x66lowId\x18\x02 \x01(\t\"\x1f\n\x11\x46lowInstanceReply\x12\n\n\x02id\x18\x01 \x01(\t\"\x9d\x01\n\x14\x41\x63tionExecuteRequest\x12\x0e\n\x06\x66lowId\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x16\n\x0e\x66lowInstanceId\x18\x03 \x01(\t\x12\x0e\n\x06\x64\x61taIn\x18\x04 \x01(\t\x12\x0e\n\x06params\x18\x05 \x01(\t\x12\x18\n\x10implementationId\x18\x36 \x01(\t\x12\x15\n\rimplementerId\x18\x37 \x01(\t\"A\n\x12\x41\x63tionExecuteReply\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07\x64\x61taOut\x18\x02 \x01(\t\x12\x0e\n\x06params\x18\x03 \x01(\t2d\n\x0b\x41\x63tionsHost\x12U\n\rexecuteAction\x12!.colabo.flow.ActionExecuteRequest\x1a\x1f.colabo.flow.ActionExecuteReply\"\x00\x32\xbf\x01\n\tFlowsHost\x12W\n\x11startFlowInstance\x12 .colabo.flow.FlowInstanceRequest\x1a\x1e.colabo.flow.FlowInstanceReply\"\x00\x12Y\n\x11\x65xecuteActionSync\x12!.colabo.flow.ActionExecuteRequest\x1a\x1f.colabo.flow.ActionExecuteReply\"\x00\x62\x06proto3')
)




_FLOWINSTANCEREQUEST = _descriptor.Descriptor(
  name='FlowInstanceRequest',
  full_name='colabo.flow.FlowInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='flowId', full_name='colabo.flow.FlowInstanceRequest.flowId', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40,
  serialized_end=77,
)


_FLOWINSTANCEREPLY = _descriptor.Descriptor(
  name='FlowInstanceReply',
  full_name='colabo.flow.FlowInstanceReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='colabo.flow.FlowInstanceReply.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=110,
)


_ACTIONEXECUTEREQUEST = _descriptor.Descriptor(
  name='ActionExecuteRequest',
  full_name='colabo.flow.ActionExecuteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='flowId', full_name='colabo.flow.ActionExecuteRequest.flowId', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='colabo.flow.ActionExecuteRequest.name', index=1,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flowInstanceId', full_name='colabo.flow.ActionExecuteRequest.flowInstanceId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataIn', full_name='colabo.flow.ActionExecuteRequest.dataIn', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='params', full_name='colabo.flow.ActionExecuteRequest.params', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='implementationId', full_name='colabo.flow.ActionExecuteRequest.implementationId', index=5,
      number=54, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='implementerId', full_name='colabo.flow.ActionExecuteRequest.implementerId', index=6,
      number=55, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=113,
  serialized_end=270,
)


_ACTIONEXECUTEREPLY = _descriptor.Descriptor(
  name='ActionExecuteReply',
  full_name='colabo.flow.ActionExecuteReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='colabo.flow.ActionExecuteReply.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataOut', full_name='colabo.flow.ActionExecuteReply.dataOut', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='params', full_name='colabo.flow.ActionExecuteReply.params', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=272,
  serialized_end=337,
)

DESCRIPTOR.message_types_by_name['FlowInstanceRequest'] = _FLOWINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['FlowInstanceReply'] = _FLOWINSTANCEREPLY
DESCRIPTOR.message_types_by_name['ActionExecuteRequest'] = _ACTIONEXECUTEREQUEST
DESCRIPTOR.message_types_by_name['ActionExecuteReply'] = _ACTIONEXECUTEREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FlowInstanceRequest = _reflection.GeneratedProtocolMessageType('FlowInstanceRequest', (_message.Message,), dict(
  DESCRIPTOR = _FLOWINSTANCEREQUEST,
  __module__ = 'colabo.flow.go.go_pb2'
  # @@protoc_insertion_point(class_scope:colabo.flow.FlowInstanceRequest)
  ))
_sym_db.RegisterMessage(FlowInstanceRequest)

FlowInstanceReply = _reflection.GeneratedProtocolMessageType('FlowInstanceReply', (_message.Message,), dict(
  DESCRIPTOR = _FLOWINSTANCEREPLY,
  __module__ = 'colabo.flow.go.go_pb2'
  # @@protoc_insertion_point(class_scope:colabo.flow.FlowInstanceReply)
  ))
_sym_db.RegisterMessage(FlowInstanceReply)

ActionExecuteRequest = _reflection.GeneratedProtocolMessageType('ActionExecuteRequest', (_message.Message,), dict(
  DESCRIPTOR = _ACTIONEXECUTEREQUEST,
  __module__ = 'colabo.flow.go.go_pb2'
  # @@protoc_insertion_point(class_scope:colabo.flow.ActionExecuteRequest)
  ))
_sym_db.RegisterMessage(ActionExecuteRequest)

ActionExecuteReply = _reflection.GeneratedProtocolMessageType('ActionExecuteReply', (_message.Message,), dict(
  DESCRIPTOR = _ACTIONEXECUTEREPLY,
  __module__ = 'colabo.flow.go.go_pb2'
  # @@protoc_insertion_point(class_scope:colabo.flow.ActionExecuteReply)
  ))
_sym_db.RegisterMessage(ActionExecuteReply)



_ACTIONSHOST = _descriptor.ServiceDescriptor(
  name='ActionsHost',
  full_name='colabo.flow.ActionsHost',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=339,
  serialized_end=439,
  methods=[
  _descriptor.MethodDescriptor(
    name='executeAction',
    full_name='colabo.flow.ActionsHost.executeAction',
    index=0,
    containing_service=None,
    input_type=_ACTIONEXECUTEREQUEST,
    output_type=_ACTIONEXECUTEREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_ACTIONSHOST)

DESCRIPTOR.services_by_name['ActionsHost'] = _ACTIONSHOST


_FLOWSHOST = _descriptor.ServiceDescriptor(
  name='FlowsHost',
  full_name='colabo.flow.FlowsHost',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  serialized_start=442,
  serialized_end=633,
  methods=[
  _descriptor.MethodDescriptor(
    name='startFlowInstance',
    full_name='colabo.flow.FlowsHost.startFlowInstance',
    index=0,
    containing_service=None,
    input_type=_FLOWINSTANCEREQUEST,
    output_type=_FLOWINSTANCEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='executeActionSync',
    full_name='colabo.flow.FlowsHost.executeActionSync',
    index=1,
    containing_service=None,
    input_type=_ACTIONEXECUTEREQUEST,
    output_type=_ACTIONEXECUTEREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_FLOWSHOST)

DESCRIPTOR.services_by_name['FlowsHost'] = _FLOWSHOST

# @@protoc_insertion_point(module_scope)



from setuptools import setup, find_packages

# read the contents of your README file
from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='colabo.flow.go',
    # other arguments omitted
    long_description=long_description,
    long_description_content_type='text/markdown',
    version='0.2.1',
    url='https://github.com/Cha-OS/colabo',
    # download_url,
    project_urls={
        'website': 'http://colabo.space',
        'organization': 'http://cha-os.org'
    },
    author='ChaOS',
    author_email='chaos.ngo@gmail.com',
    license='MIT',
    description='A python puzzle for sending ColaboFlow.Go (CF.Go) actions over gRPC',
    keywords=['colabo','grpc','flow','colaboflow', 'go', 'process', 'process mining'],
    packages=find_packages(),
    # requires=['grpcio', 'googleapis-common-protos', 'python-dateutil'],
    install_requires=['grpcio', 'googleapis-common-protos', 'python-dateutil']
)
